@@ -1,6 +1,6 @@
 /* Etherape
  * Copyright (C) 2000 Juan Toledo
- * $Id: info_windows.h,v 1.6 2003/04/06 13:45:42 bchiara Exp $
+ * $Id: info_windows.h,v 1.10 2006/01/11 20:05:50 bchiara Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,21 +21,13 @@
 #include <gtk/gtkclist.h>
 #include <gtk/gtkcheckmenuitem.h>
 
-typedef struct
-{
-  guint8 *node_id;
-  GtkWidget *window;
-}
-node_info_window_t;
-
-typedef struct
-{
-  gchar *prot_name;
-  GtkWidget *window;
-}
-prot_info_window_t;
+void node_info_window_create(const node_id_t * node_id);
+guint update_info_windows (void);
+void node_protocols_window_create(const node_id_t * node_id);
+void link_info_window_create(const link_id_t * link_id);
 
 
+/* callbacks */
 gboolean on_prot_table_button_press_event (GtkWidget * widget,
 					   GdkEventButton * event,
 					   gpointer user_data);
@@ -47,3 +39,10 @@ gboolean on_prot_list_select_row (GtkTreeView * gv, gboolean arg1,
 				  gpointer ud);
 gboolean on_delete_protocol_window (GtkWidget * wdg, GdkEvent * e,
 				    gpointer ud);
+void on_protocols_check_activate (GtkCheckMenuItem * menuitem, gpointer user_data);
+void on_prot_color_column_activate (GtkMenuItem * gm, gpointer * user_data);
+void on_protocol_column_activate (GtkMenuItem * gm, gpointer * user_data);
+void on_instant_column_activate (GtkMenuItem * gm, gpointer * user_data);
+void on_accumulated_column_activate (GtkMenuItem * gm, gpointer * user_data);
+void on_heard_column_activate (GtkMenuItem * gm, gpointer * user_data);
+void on_packets_column_activate (GtkMenuItem * gm, gpointer * user_data);
